@@ -1,5 +1,5 @@
 use bevy::prelude::*;
-use bevy_console::*;
+use bevy_console::{ConsoleConfiguration, ConsolePlugin, ToggleConsoleKey};
 
 fn main() {
     App::new()
@@ -7,8 +7,9 @@ fn main() {
         .add_plugin(ConsolePlugin)
         .insert_resource(ConsoleConfiguration {
             keys: vec![
-                ToggleConsoleKey::ScanCode(41), // this is the console key on a swedish keyboard
+                ToggleConsoleKey::ScanCode(41), // Console key on a swedish keyboard
                 ToggleConsoleKey::KeyCode(KeyCode::Grave), // US console key
+                ToggleConsoleKey::KeyCode(KeyCode::F1),
             ],
             ..Default::default()
         })
